#[repr(C)]pub struct CalmarRatio {
pub period: usize,
}Expand description
Calculates the Calmar Ratio for returns.
The Calmar Ratio is a function of the fund’s average compounded annual rate of return versus its maximum drawdown. The higher the Calmar ratio, the better it performed on a risk-adjusted basis during the given time frame.
Formula: Calmar Ratio = CAGR / |Max Drawdown|
Reference: Young, T. W. (1991). “Calmar Ratio: A Smoother Tool”. Futures, 20(1).
Fields
period: usizeThe number of periods per year for CAGR calculation (e.g., 252 for trading days).
Implementations
Sourceimpl CalmarRatio
impl CalmarRatio
Sourcepub fn new(period: Option<usize>) -> Self
pub fn new(period: Option<usize>) -> Self
Creates a new CalmarRatio instance.